@@ -89,6 +89,23 @@ class CDx_Data():
     def __getitem__(self, n):
         return self.select_by_sample_ids([self.cli.sampleId.iloc[n]])
 
+    def __sub__(self, cdx):
+        cli = pd.concat([self.cli, cdx.cli]).drop_duplicates(keep=False)
+        mut = pd.concat([self.mut, cdx.mut]).drop_duplicates(keep=False)
+        cnv = pd.concat([self.cnv, cdx.cnv]).drop_duplicates(keep=False)
+        sv = pd.concat([self.sv, cdx.sv]).drop_duplicates(keep=False)
+
+        return CDx_Data(cli_df=cli, mut_df=mut, cnv_df=cnv, sv_df=sv)
+
+    def __add__(self,cdx):
+        cli = pd.concat([self.cli, cdx.cli]).drop_duplicates()
+        mut = pd.concat([self.mut, cdx.mut]).drop_duplicates()
+        cnv = pd.concat([self.cnv, cdx.cnv]).drop_duplicates()
+        sv = pd.concat([self.sv, cdx.sv]).drop_duplicates()
+
+        return CDx_Data(cli_df=cli, mut_df=mut, cnv_df=cnv, sv_df=sv)
+
+
     def from_PETA(self, token: str, json_str: str):
         """Retrieve CDx data from BGI-PETA database. 
 
@@ -108,16 +125,23 @@ class CDx_Data():
         self.sv = peta.fetch_sv_data()
 
         # dedup for the same sampleId in different studyIds, discard the duplicated ones from all tables
-        cli_original=self.cli
-        self.cli=self.cli.drop_duplicates(subset=['sampleId','studyId'])
-        if(len(self.cli)<len(cli_original)):
+        cli_original = self.cli
+        self.cli = self.cli.drop_duplicates(subset=['sampleId', 'studyId'])
+        if (len(self.cli) < len(cli_original)):
             print('Duplicated sampleId exists, drop duplicates and go on')
 
-        undup_tuple=[(x,y) for x,y in zip(self.cli.sampleId,self.cli.studyId)]
+        undup_tuple = [(x, y)
+                       for x, y in zip(self.cli.sampleId, self.cli.studyId)]
 
-        self.sv=self.sv[self.sv.apply(lambda x: (x['Tumor_Sample_Barcode'],x['studyId']) in undup_tuple,axis=1)]
-        self.cnv=self.cnv[self.cnv.apply(lambda x: (x['Tumor_Sample_Barcode'],x['studyId']) in undup_tuple,axis=1)]
-        self.mut=self.mut[self.mut.apply(lambda x: (x['Tumor_Sample_Barcode'],x['studyId']) in undup_tuple,axis=1)]
+        self.sv = self.sv[self.sv.apply(
+            lambda x: (x['Tumor_Sample_Barcode'], x['studyId']) in undup_tuple,
+            axis=1)]
+        self.cnv = self.cnv[self.cnv.apply(
+            lambda x: (x['Tumor_Sample_Barcode'], x['studyId']) in undup_tuple,
+            axis=1)]
+        self.mut = self.mut[self.mut.apply(
+            lambda x: (x['Tumor_Sample_Barcode'], x['studyId']) in undup_tuple,
+            axis=1)]
 
         # time series
         self.cli = self._infer_datetime_columns()
@@ -479,9 +503,9 @@ class CDx_Data():
         if self.mut is None:
             raise VariantUndefinedError(f'mut variant undefied')
 
-        self.mut = self._selector(self.mut, kwargs)
+        mut = self._selector(self.mut, kwargs)
         return CDx_Data(cli_df=self.cli,
-                        mut_df=self.mut,
+                        mut_df=mut,
                         cnv_df=self.cnv,
                         sv_df=self.sv)
 
@@ -497,10 +521,10 @@ class CDx_Data():
         if self.cnv is None:
             raise VariantUndefinedError(f'cnv variant undefied')
 
-        self.cnv = self._selector(self.cnv, kwargs)
+        cnv = self._selector(self.cnv, kwargs)
         return CDx_Data(cli_df=self.cli,
                         mut_df=self.mut,
-                        cnv_df=self.cnv,
+                        cnv_df=cnv,
                         sv_df=self.sv)
 
     def set_sv_eligibility(self, **kwargs):
@@ -515,11 +539,11 @@ class CDx_Data():
         if self.sv is None:
             raise VariantUndefinedError(f'sv variant undefied')
 
-        self.sv = self._selector(self.sv, kwargs)
+        sv = self._selector(self.sv, kwargs)
         return CDx_Data(cli_df=self.cli,
                         mut_df=self.mut,
                         cnv_df=self.cnv,
-                        sv_df=self.sv)
+                        sv_df=sv)
 
     # 指定一个列名，再指定范围。离散型用数组，数值型
     # attrdict={'Cancer_type':['lung','CRC'],'Age':'x>5'}
